.. currentmodule:: py3nj

#############
API reference
#############

This page provides an auto-generated summary of py3nj's API. For more details
and examples, refer to the relevant chapters in the main part of the
documentation.

Top-level functions
===================

.. autosummary::
   :toctree: generated/

   wigner3j
   wigner6j
   wigner9j
   clebsch_gordan

Wigner module
=============

.. autosummary::
   :toctree: generated/

   wigner.drc3jj
   wigner.drc6j
